@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use English qw< -no_match_vars >;
 use Data::Dumper;
-our $VERSION = '0.724';
+our $VERSION = '0.726';
 
 use Log::Log4perl::Tiny qw< :easy :dead_if_first >;
 
@@ -22,7 +22,8 @@ my %global_defaults = (
 );
 
 sub parse_by_format {
-   my %args = normalize_args(@_, {%global_defaults,});
+   my %args = normalize_args(@_,
+      [{%global_defaults, name => 'parse by format'}, 'format']);
    identify(\%args);
 
    my $format = $args{format};
@@ -56,7 +57,8 @@ sub parse_by_format {
 
 sub parse_by_regex {
    my %args =
-     normalize_args(@_, {%global_defaults, name => 'parse by regex'});
+     normalize_args(@_,
+      [{%global_defaults, name => 'parse by regex'}, 'regex']);
    identify(\%args);
 
    my $name  = $args{name};
@@ -113,15 +115,22 @@ sub parse_by_separators {
 
    # this sub will use the regexp above, do checking and return captured
    # values in a hash with @keys
-   my $n_keys     = scalar @$keys;
-   my $input      = $args{input};
-   my $output     = $args{output};
+   my $n_keys       = scalar @$keys;
+   my $name         = $args{name};
+   my $input        = $args{input};
+   my $output       = $args{output};
+
    return sub {
       my $record = shift;
       my @values = $record->{$input} =~ m{$regex}
         or die {message => 'invalid record', record => $record};
-      die      {message => "invalid record, wrong number of items", record => $record}
-        if scalar(@values) != $n_keys;
+      my $n_values = @values;
+      die {
+         message => "'$name': invalid record, expected $n_keys items, "
+           . "got $n_values",
+         record => $record
+        }
+        if $n_values != $n_keys;
       $record->{$output} = \my %retval;
       @retval{@$keys} = @values;
       return $record;
@@ -130,7 +139,8 @@ sub parse_by_separators {
 
 sub parse_by_split {
    my %args =
-     normalize_args(@_, {%global_defaults, name => 'parse by split'});
+     normalize_args(@_,
+      [{%global_defaults, name => 'parse by split'}, 'separator']);
    identify(\%args);
 
    my $name      = $args{name};
@@ -142,10 +152,11 @@ sub parse_by_split {
       $separator = qr{$separator};
    }
 
-   my $keys   = $args{keys};
-   my $n_keys = defined($keys) ? scalar(@$keys) : 0;
-   my $input  = $args{input};
-   my $output = $args{output};
+   my $keys         = $args{keys};
+   my $n_keys       = defined($keys) ? scalar(@$keys) : 0;
+   my $input        = $args{input};
+   my $output       = $args{output};
+   my $allow_missing = $args{allow_missing} || 0;
 
    return sub {
       my $record = shift;
@@ -158,7 +169,7 @@ sub parse_by_split {
          input  => $input,
          record => $record,
         }
-        if $n_values != $n_keys;
+        if $n_values + $allow_missing < $n_keys;
 
       $record->{$output} = \my %retval;
       @retval{@$keys} = @values;
